@@ -1,6 +1,7 @@
 from ..interface.others import Variable
 import argparse
 from .types import *
+from YTools.universe import beautiful_str
 
 class Argument:
 	def __init__(self , name , type , default , editable):
@@ -13,12 +14,22 @@ class ArgProxy:
 	def __init__(self , name = None):
 		self.name = name
 		self.args = []
+		self.name2arg = {}
+
+	def process_name(self , name):
+		return name.strip().replace(" " , "_")
 
 	def add_argument(self , name , type = str , default = None , editable = False):
-		self.args.append(Argument(name , type , default , editable = editable))
+		name = self.process_name(name)
+		arg = Argument(name , type , default , editable = editable)
+		self.args.append(arg)
+		self.name2arg[name] = arg
 
 	def add_store_true(self , name , editable = False):
-		self.args.append(Argument(name , Bool , "False" , editable = editable))
+		name = self.process_name(name)
+		arg = Argument(name , Bool , "False" , editable = editable)
+		self.args.append(arg)
+		self.name2arg[name] = arg
 
 	def assign_from_cmd(self , args = None):
 		C = argparse.ArgumentParser()
@@ -33,3 +44,8 @@ class ArgProxy:
 
 		return C
 
+	def __str__(self):
+		return beautiful_str(["name" , "default" , "type"] , [
+			[x.name , x.default , x.type] for x in self.args
+		])
+
