@@ -1,4 +1,5 @@
 from .displays import *
-from .new_methods import *
 from .group_opt import *
-from .variable_opt import *
\ No newline at end of file
+from .variable_opt import *
+from .project_opt import *
+from .experiment_opt import *
